/*
 * Copyright (c) 2022-2023 Datalayer Inc. All rights reserved.
 *
 * MIT License
 */
import { BoxPanel } from '@lumino/widgets';
import { TerminalManager } from '@jupyterlab/services';
import { Terminal as JupyterTerminal } from '@jupyterlab/terminal';
export class TerminalAdapter {
    terminal;
    terminalPanel;
    constructor(options) {
        const { serverSettings, theme } = options;
        this.terminalPanel = new BoxPanel();
        this.terminalPanel.spacing = 0;
        this.terminalPanel.addClass("dla-JupyterLab-Terminal-id");
        const terminalManager = new TerminalManager({
            serverSettings,
        });
        terminalManager.startNew().then((terminalConnection) => {
            terminalConnection.connectionStatusChanged.connect((_, status) => {
                console.log('Jupyter Terminal status', status);
            });
            this.terminal = new JupyterTerminal(terminalConnection, { theme });
            this.terminal.title.closable = true;
            this.terminalPanel.addWidget(this.terminal);
        });
    }
    get panel() {
        return this.terminalPanel;
    }
    setTheme(theme) {
        this.terminal.setOption('theme', theme);
    }
}
export default TerminalAdapter;
//# sourceMappingURL=TerminalAdapter.js.map